@@ -35,7 +35,7 @@ class TextSetup:
 
 class SwachhText(TextSetup):
     def __init__(self, TextSetup):
-        self.t = setup.t
+        self.t = TextSetup.t
         self.text = self.t
         self.dtype_str = isinstance(self.text, str)
         self.dtype_list = isinstance(self.text, list)
